@@ -926,13 +926,13 @@ public final class DBCassandraAstyanaxImpl implements DatabookStore {
 	}
 	/**
 	 * called when you add new notification types where the setting does not exist yet
-	 * please note: by default we set only portal notifications
+	 * please note: by default we set all notifications
 	 */
 	private List<NotificationChannelType> createNewNotificationType(String userid, NotificationType notificationType) {
 		List<NotificationChannelType> toReturn = new ArrayList<NotificationChannelType>();
 		MutationBatch m = conn.getKeyspace().prepareMutationBatch();
 		String valueToInsert = "";
-		NotificationChannelType[] wpTypes = { NotificationChannelType.PORTAL };
+		NotificationChannelType[] wpTypes = NotificationChannelType.values();
 		
 		for (int i = 0; i < wpTypes.length; i++) {
 			valueToInsert += wpTypes[i];
